module Pages.Arguments exposing (Model, Msg, page)

import Config.Colour as T exposing (..)
import Config.Format as O exposing (..)
import Config.Identity as I exposing (..)
import Debate.Arguments.Abortion exposing (..)
import Debate.Arguments.Agnosticism exposing (..)
import Debate.Arguments.AgriculturalPredation exposing (..)
import Debate.Arguments.AnabolicKeto exposing (..)
import Debate.Arguments.AnimalRights exposing (..)
import Debate.Arguments.AntagonisticPleiotropy exposing (..)
import Debate.Arguments.AntiRewilding exposing (..)
import Debate.Arguments.AntiVandalism exposing (..)
import Debate.Arguments.ApoBCVD exposing (..)
import Debate.Arguments.BoobyTrapPagers exposing (..)
import Debate.Arguments.CarbsObesity exposing (..)
import Debate.Arguments.ColonizingNature exposing (..)
import Debate.Arguments.CropDeaths exposing (..)
import Debate.Arguments.DairyCowRape exposing (..)
import Debate.Arguments.DietaryCholesterol exposing (..)
import Debate.Arguments.EfilismPatrolSquad exposing (..)
import Debate.Arguments.EpidemiologyCausality exposing (..)
import Debate.Arguments.EthicalSlurs exposing (..)
import Debate.Arguments.FineTuning exposing (..)
import Debate.Arguments.FlatEarthDebunk exposing (..)
import Debate.Arguments.FructoseNAFLD exposing (..)
import Debate.Arguments.HealthPromotingFoods exposing (..)
import Debate.Arguments.HealthSeeker exposing (..)
import Debate.Arguments.HealthyChocolate exposing (..)
import Debate.Arguments.HealthyDairy exposing (..)
import Debate.Arguments.HealthyFattyFish exposing (..)
import Debate.Arguments.HealthyFibre exposing (..)
import Debate.Arguments.HealthyFood exposing (..)
import Debate.Arguments.HealthyPlantFoods exposing (..)
import Debate.Arguments.HealthySeedOils exposing (..)
import Debate.Arguments.HealthySoy exposing (..)
import Debate.Arguments.ImmortalityReductio exposing (..)
import Debate.Arguments.Malondialdehyde exposing (..)
import Debate.Arguments.OddOrderPredators exposing (..)
import Debate.Arguments.Omega3Omega6Ratio exposing (..)
import Debate.Arguments.Ostroveganism exposing (..)
import Debate.Arguments.PlantBasedCVDReversal exposing (..)
import Debate.Arguments.PollinationReductio exposing (..)
import Debate.Arguments.PolyphenolReductio exposing (..)
import Debate.Arguments.ScratcherPioneers exposing (..)
import Debate.Arguments.SodiumCVD exposing (..)
import Debate.Arguments.TMAOCausality exposing (..)
import Debate.Arguments.Template exposing (argument)
import Debate.Arguments.TransPeople exposing (..)
import Debate.Arguments.TruncatedMeta exposing (..)
import Debate.Arguments.UnhealthyCoconutOil exposing (..)
import Debate.Arguments.UnhealthyProcessedMeat exposing (..)
import Debate.Arguments.UnhealthyRedMeat exposing (..)
import Debate.Arguments.UnhealthySaturatedFat exposing (..)
import Debate.Arguments.VeganSocietyReductio exposing (..)
import Debate.Gibberish.Helpers exposing (..)
import Debate.Helpers exposing (..)
import Debate.Types exposing (..)
import Effect exposing (Effect)
import Element exposing (..)
import Element.Border as D exposing (..)
import Element.Font as F
import Headers.Helpers exposing (headerMaker)
import Headers.Pages.Arguments exposing (argumentHeader)
import Html
import Html.Attributes as H exposing (style, title, wrap)
import Layouts
import List.Extra as L exposing (..)
import Page exposing (Page)
import Ports exposing (gotArgHeight)
import Route exposing (Route)
import Shared
import View exposing (View)


page : Shared.Model -> Route () -> Page Model Msg
page shared route =
    Page.new
        { init = init
        , update = update
        , subscriptions = subscriptions
        , view = view
        }
        |> Page.withLayout toLayout


toLayout : Model -> Layouts.Layout Msg
toLayout model =
    Layouts.Navbar {}



-- INIT


type alias Model =
    {}


init : () -> ( Model, Effect Msg )
init () =
    ( {}
    , Effect.none
    )



-- UPDATE


type Msg
    = NoOp


update : Msg -> Model -> ( Model, Effect Msg )
update msg model =
    case msg of
        NoOp ->
            ( model
            , Effect.none
            )



-- SUBSCRIPTIONS


subscriptions : Model -> Sub Msg
subscriptions model =
    Sub.none



-- VIEW


view : Model -> View Msg
view model =
    { title = debateName
    , attributes = []
    , element = debateContainer
    }


debateContainer : Element msg
debateContainer =
    topLevelContainer debateList


debateList : Element msg
debateList =
    column [ centerX ]
        [ column
            pageList
          <|
            List.concat
                [ List.map headerMaker
                    [ argumentHeader ]
                , List.map argumentMaker
                    [ argumentApoBCVD
                    , argumentAnabolicKeto
                    , argumentAntagonisticPleiotropy
                    , argumentCarbsObesity
                    , argumentDietaryCholesterol
                    , argumentFructoseNAFLD
                    , argumentHealthPromotingFoods
                    , argumentHealthSeeker
                    , argumentHealthyChocolate
                    , argumentHealthyDairy
                    , argumentHealthyFattyFish
                    , argumentHealthyFibre
                    , argumentHealthyFood
                    , argumentHealthyPlantFoods
                    , argumentHealthySeedOils
                    , argumentHealthySoy
                    , argumentMalondialdehyde
                    , argumentOmega3Omega6Ratio
                    , argumentPlantBasedCVDReversal
                    , argumentPolyphenolReductio
                    , argumentSodiumCVD
                    , argumentTMAOCausality
                    , argumentUnhealthyCoconutOil
                    , argumentUnhealthyProcessedMeat
                    , argumentUnhealthyRedMeat
                    , argumentUnhealthySaturatedFat
                    , argumentAbortion
                    , argumentAgnosticism
                    , argumentAgriculturalPredation
                    , argumentAnimalRights
                    , argumentAntiRewilding
                    , argumentAntiVandalism
                    , argumentColonizingNature
                    , argumentCropDeaths
                    , argumentDairyCowRape
                    , argumentEfilismPatrolSquad
                    , argumentEthicalSlurs
                    , argumentFineTuning
                    , argumentImmortalityReductio
                    , argumentOddOrderPredators
                    , argumentOstroveganism
                    , argumentPollinationReductio
                    , argumentScratcherPioneers
                    , argumentTransPeople
                    , argumentVeganSocietyReductio
                    , argumentBoobyTrapPagers
                    , argumentEpidemiologyCausality
                    , argumentFlatEarthDebunk
                    , argumentTruncatedMeta
                    ]
                , List.map gibberishMaker
                    [ gibberishList ]
                ]
        ]
