module Pages.Interviews exposing (Model, Msg, page)

import Config.Colour as T exposing (..)
import Config.Format as O exposing (..)
import Config.Identity as I exposing (..)
import Effect exposing (Effect)
import Element exposing (..)
import Element.Border as D
import Element.Font as F
import Headers.Helpers exposing (headerMaker)
import Headers.Pages.Interviews exposing (interviewHeader)
import Html
import Html.Attributes as H exposing (style)
import Interviews.Episodes.DrShawnBakerPodcast exposing (drShawnBakerPodcast)
import Interviews.Episodes.FitAndFurious exposing (fitAndFurious)
import Interviews.Episodes.FoolproofMastery exposing (foolproofMastery)
import Interviews.Episodes.KetogeeksPodcast exposing (ketoGeeksPodcast)
import Interviews.Episodes.LegendaryLifePodcast exposing (legendaryLifePodcast)
import Interviews.Episodes.MarkBellsPowerProject exposing (markBellsPowerProject)
import Interviews.Episodes.MuscleMemoirsPodcast exposing (muscleMemoirsPodcast)
import Interviews.Episodes.SigmaNutritionRadio exposing (sigmaNutritionRadio)
import Interviews.Episodes.StrenuousLifePodcast exposing (strenuousLifePodcast)
import Interviews.Helpers exposing (..)
import Layouts
import List exposing (head)
import Page exposing (Page)
import Route exposing (Route)
import Shared
import View exposing (View)


page : Shared.Model -> Route () -> Page Model Msg
page shared route =
    Page.new
        { init = init
        , update = update
        , subscriptions = subscriptions
        , view = view
        }
        |> Page.withLayout toLayout


toLayout : Model -> Layouts.Layout Msg
toLayout model =
    Layouts.Navbar {}



-- INIT


type alias Model =
    {}


init : () -> ( Model, Effect Msg )
init () =
    ( {}
    , Effect.none
    )



-- UPDATE


type Msg
    = NoOp


update : Msg -> Model -> ( Model, Effect Msg )
update msg model =
    case msg of
        NoOp ->
            ( model
            , Effect.none
            )



-- SUBSCRIPTIONS


subscriptions : Model -> Sub Msg
subscriptions model =
    Sub.none



-- VIEW


view : Model -> View Msg
view model =
    { title = interviewsName
    , attributes = []
    , element = interviewContainer
    }


interviewContainer : Element msg
interviewContainer =
    topLevelContainer interviewList


interviewList : Element msg
interviewList =
    column
        pageList
    <|
        List.concat
            [ List.map headerMaker
                [ interviewHeader ]
            , List.map interviewMaker
                [ sigmaNutritionRadio
                , markBellsPowerProject
                , foolproofMastery
                , ketoGeeksPodcast
                , legendaryLifePodcast
                , muscleMemoirsPodcast
                , fitAndFurious
                , strenuousLifePodcast
                , drShawnBakerPodcast
                ]
            ]
